pyLanguagetool
==============

This is a python library and CLI for the LanguageTool_ `JSON API`_.


.. _LanguageTool: https://languagetool.org/

.. _JSON API: https://languagetool.org/http-api/swagger-ui/#/default